@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 1;
 
@@ -30,7 +30,8 @@ L<PYX::GraphViz>,
 L<PYX::Hist>,
 L<PYX::Parser>,
 L<PYX::Stack>,
-L<PYX::Utils>.
+L<PYX::Utils>,
+L<Tags::Output::PYX>.
 
 =head1 REPOSITORY
 
@@ -50,6 +51,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
